ticker library

Classes

CharacterIndices
Class to hold the start and end indices for character animations
LevenshteinUtils
Helper class to compute the Levenshtein distance between two strings. Used for determining the optimal animation path between two strings. https://en.wikipedia.org/wiki/Levenshtein_distance
TickerAnimationStartConfig
Configuration class for controlling how ticker animations start This configuration only applies to the initial/first animation to preserve fluidity
TickerCharacterList
This is the primary class that Ticker uses to determine how to animate from one character to another. The provided string dictates what characters will appear between the start and end characters.
TickerColumn
/ Represents a column of characters to be drawn on the screen. This class primarily handles animating within the column from one character to the next and drawing all of the intermediate states.
TickerColumnManager
In ticker, each character in the rendered text is represented by a TickerColumn. The column can be seen as a column of text in which we can animate from one character to the next by scrolling the column vertically. The TickerColumnManager is then a manager/convenience class for handling a list of TickerColumn which then combines into the entire string we are rendering.
TickerDrawMetrics
This class represents core drawing metrics that the Ticker widget requires to calculate positions and offsets for rendering text onto the canvas.
TickerUtils
Utility class for the ticker package. Contains helper methods such as those that generate default character lists to use for animation.
TickerWidget
The primary widget for showing a ticker text view that handles smoothly scrolling from the current text to a given text. The scrolling behavior is defined by the character lists which dictate what characters come in between the starting and ending characters.
TickerWidgetState

Enums

ScrollingDirection
Enum for scrolling direction
TickerAnimationStartMode
Enum for different animation starting behaviors