This is the primary class that Ticker uses to determine how to animate from one character
to another. The provided string dictates what characters will appear between
the start and end characters.
/ Represents a column of characters to be drawn on the screen.
This class primarily handles animating within the column from one character
to the next and drawing all of the intermediate states.
In ticker, each character in the rendered text is represented by a TickerColumn. The
column can be seen as a column of text in which we can animate from one character to the next
by scrolling the column vertically. The TickerColumnManager is then a
manager/convenience class for handling a list of TickerColumn which then combines into
the entire string we are rendering.
The primary widget for showing a ticker text view that handles smoothly scrolling from the
current text to a given text. The scrolling behavior is defined by
the character lists which dictate what characters come in between the starting
and ending characters.